connect 'jdbc:derby://localhost:1527/c:\derby10.1.1\OPTIM\optim;create=true';

--
-- create legacy demo tables
-- schema now renamed to demo
--
drop table demo.details;
drop table demo.items;
drop table demo.orders;
drop table demo.customers;
drop table demo.sales;
drop table demo.state;
drop table demo.ship_to;
drop table demo.ship_instr;
drop table demo.male_rates;
drop table demo.female_rates;
drop schema demo restrict;

create schema demo;

--table demo.sales
create table demo.sales
       (salesman_id       char(6)        not null,
        salesman_name     char(20)       not null,
        age               integer        not null with default 0,
        sex               char(1)        not null with default ' ',
        territory         varchar(14)    not null,
        manager_id        char(6));

--unique index demo.xsalespk for table demo.sales
create unique index demo.xsalespk
        on demo.sales
       (salesman_id       asc);

--primary key demo.sales
alter table demo.sales
        add primary key 
       (salesman_id);

--table demo.customers
create table demo.customers
       (cust_id           char(5)        not null,
        custname          char(20)       not null,
        address           varchar(50)    not null,
        city              varchar(15)    not null,
        state             char(2)        not null,
        zip               char(5),
        ytd_sales         decimal(7, 2)  not null with default 0,
        salesman_id       char(6),
        phone_number      char(10),
        nationality       varchar(30),
        national_id       varchar(30),
        creditcard_number varchar(16),
        creditcard_type   varchar(30),
        creditcard_exp    char(4),
        creditcard_cvv    varchar(4),
        email_address     varchar(50));


--unique index demo.xcustpk for table demo.customers
create unique index demo.xcustpk
        on demo.customers
       (cust_id asc);

--primary key for table demo.customers
alter table demo.customers
        add primary key 
       (cust_id);

--relationship rsc between demo.sales and demo.customers
alter table demo.customers
        add constraint rsc 
        foreign key 
        (salesman_id) 
        references demo.sales (salesman_id)
        on delete set null;

--table demo.orders
create table demo.orders
       (order_id          decimal(5, 0)  not null,
        cust_id           char(5)        not null,
        order_date        date           not null with default CURRENT_DATE,
        order_time        time           not null with default CURRENT_TIME,
        freight_charges   decimal(4, 2),
        order_salesman    char(6),
        order_posted_date timestamp      not null with default CURRENT_TIMESTAMP,
        order_ship_date   char(8)        with default null);

--unique index demo.xordrpk for table demo.orders
create unique index demo.xordrpk
        on demo.orders
       (order_id asc);

--primary key demo.orders
alter table demo.orders
        add primary key 
       (order_id);

--relationship rco between demo.customers and demo.orders
alter table demo.orders
         add constraint rco
        foreign key 
       (cust_id) 
        references demo.customers (cust_id)
        on delete restrict;

--table demo.items
create table demo.items
       (item_id           char(5)        not null,
        item_description  varchar(72)    not null,
        category          varchar(14)    not null,
        rating            char(4)        not null,
        unit_price        decimal(5, 2)  not null,
        on_hand_inventory integer        not null);

--unique index demo.xitempk for table demo.items
create unique index demo.xitempk
        on demo.items
       (item_id           asc);

--primary key demo.items
alter table demo.items
        add primary key 
        (item_id);

--table demo.details
create table demo.details
       (order_id          decimal(5, 0)  not null,
        item_id           char(5)        not null,
        item_quantity     smallint       not null,
        detail_unit_price decimal(5, 2)  not null);

--unique index demo.xdetlpk for table demo.details
create unique index demo.xdetlpk
        on demo.details
       (order_id          desc, 
        item_id           asc);

--primary key demo.details
alter table demo.details
        add primary key 
       (order_id, 
        item_id);

--relationship rod between demo.orders and demo.details
alter table demo.details
         add constraint rod
        foreign key  
        (order_id) 
        references demo.orders (order_id) 
        on delete cascade;

--relationship rid between demo.items and demo.details
alter table demo.details
         add constraint rid
        foreign key  
       (item_id) 
        references demo.items (item_id) 
        on delete restrict;

--table demo.ship_to
create table demo.ship_to
       (cust_id           char(5)        not null,
        ship_id           smallint       not null,
        address           varchar(50),
        city              varchar(15),
        state             char(2),
        zip               decimal(9, 0),
        in_care_of        varchar(30),
        shipping_change_dt date not null with default CURRENT_DATE);

--table demo.female_rates
create table demo.female_rates
        (age              integer,
        rate_per_1000     decimal(5, 0));

--table demo.male_rates
create table demo.male_rates
       (age               integer,
        rate_per_1000     decimal(5, 0));

--table demo.state_lookup
create table demo.state_lookup
       (district          char(2)        not null,
        dist_code         char(3)        not null);

--table demo.ship_instr
create table demo.ship_instr
       (ship_id           smallint,
        ship_instr_id     decimal(5, 0),
        order_ship_instr  varchar(254),
        ship_updated      timestamp      not null with default CURRENT_TIMESTAMP);

--unique index demo.xshipipk for table demo.ship_instr
create unique index demo.xshipipk
        on demo.ship_instr
        (ship_instr_id    asc);

--table demo.customers2
create table demo.customers2
       (cust_id           char(5)        not null,
        custname          char(20)       not null,
        address           varchar(50)    not null,
        city              varchar(15)    not null,
        state             char(2)        not null,
        zip               char(5),
        ytd_sales         decimal(7, 2)  not null with default 0,
        salesman_id       char(6),
        phone_number      char(10),
        nationality       varchar(30),
        national_id       varchar(30),
        creditcard_number varchar(16),
        creditcard_type   varchar(30),
        creditcard_exp    char(4),
        creditcard_cvv    varchar(4),
        email_address     varchar(50));

--unique index demo.xcustpk2 for table demo.customers2
create unique index demo.xcustpk2
        on demo.customers2
       (cust_id           asc);

--primary key for table demo.customers2
alter table demo.customers2
        add primary key 
       (cust_id);

--table demo.orders2
create table demo.orders2
       (order_id          decimal(5, 0)  not null,
        cust_id           char(5)        not null,
        order_date        date           not null with default CURRENT_DATE,
        order_time        time           not null with default CURRENT_TIME,
        freight_charges   decimal(4, 2),
        order_salesman    char(6),
        order_posted_date timestamp      not null with default CURRENT_TIMESTAMP,
        order_ship_date   char(8)        with default null);

--unique index demo.xordrpk2 for table demo.orders2
create unique index demo.xordrpk2
        on demo.orders2
       (order_id          asc);

--primary key demo.orders2
alter table demo.orders2
        add primary key 
       (order_id);
--relationship rco2 between demo.customers2 and demo.orders2
alter table demo.orders2
         add constraint rco2
        foreign key 
       (cust_id) 
        references demo.customers2 (cust_id)
        on delete restrict;

--table demo.items2
create table demo.items2
       (item_id           char(5)        not null,
        item_description  varchar(72)    not null,
        category          varchar(14)    not null,
        rating            char(4)        not null,
        unit_price        decimal(5, 2)  not null,
        on_hand_inventory integer        not null);

--unique index demo.xitempk2 for table demo.items2
create unique index demo.xitempk2
        on demo.items2
       (item_id           asc);

--primary key demo.items2
alter table demo.items2
        add primary key 
        (item_id);

--table demo.details2
create table demo.details2
       (order_id          decimal(5, 0)  not null,
        item_id           char(5)        not null,
        item_quantity     smallint       not null,
        detail_unit_price decimal(5, 2)  not null);

--unique index demo.xdetlpk2 for table demo.details2
create unique index demo.xdetlpk2
        on demo.details2
       (order_id          desc, 
        item_id           asc);
        
--primary key demo.details2
alter table demo.details2
        add primary key
       (order_id, 
        item_id);
        
--relationship rod2 between demo.orders2 and demo.details2
alter table demo.details2
         add constraint rod2
        foreign key
        (order_id) 
        references demo.orders2 (order_id)
        on delete cascade;
        
--relationship rid2 between demo.items2 and demo.details2
alter table demo.details2
         add constraint rid2
        foreign key 
       (item_id) 
        references demo.items2 (item_id)
        on delete restrict;
        
--table demo.actions
create table demo.actions
       (action_id            decimal(2,0)
        check ( ( ( action_id >= 0. ) and ( action_id <= 16. ) ) ),
        action_text          varchar(30),
        after_row_status     varchar(2),
        archive_desc         varchar(40),
        archive_file_name    varchar(80),
        archive_id           decimal(5,0),
        current_datetime     timestamp,
        group_name           varchar(8),
        index_file_name      varchar(80),
        machine_name         varchar(15),
        server_name          varchar(15),
        start_datetime       timestamp,
        source_tbl_dbalias   varchar(15),
        dest_tbl_dbalias     varchar(15),
        source_tbl_name      varchar(40),
        dest_tbl_name        varchar(40),
        tbl_row_in_error     decimal(9,0),
        tbl_row_processed    decimal(9,0),
        rows_left_t_b_proc   decimal(9,0),
        tbl_row_extracted    decimal(9,0),
        source_tbl_schema    varchar(20),
        dest_tbl_schema      varchar(20),
        tot_row_in_error     decimal(9,0),
        tot_row_processed    decimal(9,0),
        tot_left_t_b_proc    decimal(9,0),
        tot_proc_status      varchar(15),
        tot_row_extracted    decimal(9,0),
        user_id              varchar(8));

