connect 'jdbc:derby://localhost:1527/c:\derby10.1.1\OPTIM\optim;create=true';

-- create optimuser2 schema
drop table optimuser2.optim_details;
drop table optimuser2.optim_items;
drop table optimuser2.optim_orders;
drop table optimuser2.optim_customers;
drop table optimuser2.optim_sales;
drop table optimuser2.optim_state_lookup;
drop table optimuser2.optim_ship_to;
drop table optimuser2.optim_ship_instr;
drop table optimuser2.optim_male_rates;
drop table optimuser2.optim_female_rates;

drop schema optimuser2 restrict;

create schema optimuser2;

create table optimuser2.OPTIM_CUSTOMERS
  (CUST_ID         char(5)      not null
  ,CUSTNAME        varchar (120) not null
  ,ADDRESS1        varchar(200) not null
  ,ADDRESS2        varchar(200) 
  ,LOCALITY        varchar(112) 
  ,CITY            varchar(120) not null
  ,STATE           varchar(40)     
  ,COUNTRY_CODE    char(5)      not null
  ,POSTAL_CODE     varchar(15)
  ,POSTAL_CODE_PLUS4     char(4)
  ,EMAIL_ADDRESS         varchar(70)
  ,PHONE_NUMBER    varchar(20) 
  ,YTD_SALES       decimal(7,2) not null default 0
  ,SALESMAN_ID     char(6)
  ,NATIONALITY     varchar(30)
  ,NATIONAL_ID     varchar(30)   
  ,CREDITCARD_NUMBER     varchar(19)
  ,CREDITCARD_TYPE   varchar(30)
  ,CREDITCARD_EXP        char(4)
  ,CREDITCARD_CVV        varchar(4)
  ,DRIVER_LICENSE        varchar(30)
  ,CREDITCARD_HISTORY   clob          );
 
alter table optimuser2.OPTIM_CUSTOMERS
  add constraint XCUSTPK
    primary key
      ( CUST_ID );
 
COMMIT;
 
create table optimuser2.OPTIM_SALES
  (SALESMAN_ID    char(6)       not null
  ,FIRST_NAME     varchar(15)   not null
  ,LAST_NAME      varchar(15)   not null
  ,NATIONALITY    varchar(30)
  ,NATIONAL_ID    varchar(30)
  ,PHONE_NUMBER   varchar(20)   not null
  ,AGE            smallint  not null default 0
  ,SEX            char(1)       not null default ' '
  ,TERRITORY      varchar(14)   not null
  ,EMAIL_ADDRESS  varchar(70)   not null
  ,MANAGER_ID     varchar(6)    );
 
alter table optimuser2.OPTIM_SALES
  add constraint XSALESPK
    primary key
      ( SALESMAN_ID );

alter table optimuser2.OPTIM_CUSTOMERS
        add constraint RSC 
        foreign key 
        (SALESMAN_ID) 
        references optimuser2.OPTIM_SALES (SALESMAN_ID)
        on delete set null;
 
COMMIT;
 
create table optimuser2.OPTIM_ORDERS
  (ORDER_ID          decimal(10,0) not null
  ,CUST_ID           char(5)      not null
  ,ORDER_DATE        timestamp   not null default CURRENT TIMESTAMP
  ,ORDER_TIME        timestamp   not null default CURRENT TIMESTAMP
  ,FREIGHT_CHARGES   decimal(4,2)
  ,ORDER_SALESMAN    char(6)
  ,ORDER_POSTED_DATE timestamp not null default CURRENT TIMESTAMP
  ,ORDER_SHIP_DATE   char(8)               default NULL );
 
alter table optimuser2.OPTIM_ORDERS
  add constraint XORDRPK
    primary key
      ( ORDER_ID );
 
alter table optimuser2.OPTIM_ORDERS
  add constraint RCO
    foreign key
      ( CUST_ID )
      references optimuser2.OPTIM_CUSTOMERS
        ( CUST_ID );
 
COMMIT;
 
create table optimuser2.OPTIM_DETAILS
  (ORDER_ID          decimal(10,0) not null
  ,ITEM_ID           char(5)      not null
  ,ITEM_QUANTITY     decimal(10,0) not null
  ,DETAIL_UNIT_PRICE decimal(5,2) not null );
 
alter table optimuser2.OPTIM_DETAILS
  add constraint XDETLPK
    primary key
      ( ORDER_ID,
        ITEM_ID );
 
alter table optimuser2.OPTIM_DETAILS
  add constraint ROD
    foreign key
      ( ORDER_ID )
      references optimuser2.OPTIM_ORDERS
        ( ORDER_ID );
 
COMMIT;
 
create table optimuser2.OPTIM_ITEMS
  (ITEM_ID           char(5)       not null
  ,ITEM_DESCRIPTION  varchar(72)   not null
  ,CATEGORY          varchar(14)   not null
  ,RATING            char(4)       not null
  ,UNIT_PRICE        decimal(5,2)  not null
  ,ON_HAND_INVENTORY decimal(10,0) not null );
 
alter table optimuser2.OPTIM_ITEMS
  add constraint XITEMPK
    primary key
      ( ITEM_ID );

 
alter table optimuser2.OPTIM_DETAILS
         add constraint RID
        foreign key  
       (ITEM_ID) 
        references optimuser2.OPTIM_ITEMS (ITEM_ID) 
        on delete restrict;
COMMIT;
 
create table optimuser2.OPTIM_SHIP_INSTR
  (SHIP_ID          decimal(10,0)
  ,SHIP_INSTR_ID    integer
  ,ORDER_SHIP_INSTR varchar(254)
  ,SHIP_UPDATED     timestamp not null default CURRENT TIMESTAMP );
 
create index XSHIPIPK
  on optimuser2.OPTIM_SHIP_INSTR
    ( SHIP_INSTR_ID ASC );
 
COMMIT;
 
create table optimuser2.OPTIM_SHIP_TO
  (CUST_ID            char(5)       not null
  ,SHIP_ID            decimal(10,0)     not null
  ,ADDRESS1           varchar(200)    
  ,ADDRESS2           varchar(200) 
  ,LOCALITY       varchar(112) 
  ,CITY               varchar(120) 
  ,STATE              char(40)
  ,COUNTRY_CODE       char(5)   not null
  ,POSTAL_CODE        varchar(15)
  ,POSTAL_CODE_PLUS4  char(4)
  ,IN_CARE_OF         varchar(31)
  ,SHIPPING_CHANGE_DT timestamp   not null default CURRENT TIMESTAMP );
 
COMMIT;
 
create table optimuser2.OPTIM_STATE_LOOKUP
  (DISTRICT  char(2) not null
  ,DIST_CODE char(3) not null );
 
COMMIT;
 
create table optimuser2.OPTIM_FEMALE_RATES
  (AGE           smallint
  ,RATE_PER_1000 decimal(10,0)                );
 
COMMIT;
 
create table optimuser2.OPTIM_MALE_RATES
  (AGE           smallint
  ,RATE_PER_1000 decimal(10,0)                );
 
COMMIT;
 
